@@ -93,7 +93,7 @@ def load_profile(profile, parser="/sbin/apparmor_parser",
     command.append(profile)
     rc, output = easyprof.cmd(command)
     if rc != 0:
-        raise AppArmorException("policy load failed with errno %d: %s" %
+        raise AppArmorException("policy load failed with exit status %d: %s" %
                                 (rc, output))
     return (rc, output)
 
@@ -127,7 +127,7 @@ def unload_profile(profile):
     try:
         apparmor_available()
     except AppArmorException as e:
-            raise AppArmorException("%s. Skipping load" % e)
+            raise AppArmorException("%s. Skipping unload" % e)
 
     apparmor_remove = os.path.join(apparmor_fs, ".remove")
     try:
@@ -144,7 +144,7 @@ def unload_profiles(profiles):
     try:
         apparmor_available()
     except AppArmorException as e:
-            raise AppArmorException("%s. Skipping load" % e)
+            raise AppArmorException("%s. Skipping unload" % e)
 
     apparmor_remove = os.path.join(apparmor_fs, ".remove")
     for profile in profiles:
@@ -356,6 +356,21 @@ class EasyprofProfile(object):
     def add_policygroup(self, policygroup):
         self.profile['policy_groups'].append(policygroup)
 
+    def add_abstraction(self, abstraction):
+        if not 'abstractions' in self.profile:
+            self.profile['abstractions'] = list()
+        self.profile['abstractions'].append(abstraction)
+
+    def add_read_path(self, read_path):
+        if not 'read_path' in self.profile:
+            self.profile['read_path'] = list()
+        self.profile['read_path'].append(read_path)
+
+    def add_write_path(self, write_path):
+        if not 'write_path' in self.profile:
+            self.profile['write_path'] = list()
+        self.profile['write_path'].append(write_path)
+
     @property
     def template(self):
         if 'template' in self.profile:
@@ -427,9 +442,12 @@ def ubuntu_1310_transform(click_manifest):
             newp.policyvendor = "ubuntu"
 
         if 'policy_version' in profile:
-            newp.policyversion = profile['policy_version']
+            # LP: #1214618. Qt json outputs 1.0 as 1. Account for that in our
+            # transmogrification to easyprof. Note, this also converts "1.0"
+            # to 1.0.
+            newp.policyversion = float(profile['policy_version'])
         else:
-            newp.policyversion = "1.0"
+            newp.policyversion = 1.0
 
         newp.add_variable("APP_PKGNAME", click_manifest.app_pkgname)
         newp.add_variable("APP_VERSION", click_manifest.app_version)
@@ -440,6 +458,18 @@ def ubuntu_1310_transform(click_manifest):
             for policygroup in profile['policy_groups']:
                 newp.add_policygroup(policygroup)
 
+        if 'abstractions' in profile:
+            for abstraction in profile['abstractions']:
+                newp.add_abstraction(abstraction)
+
+        if 'read_path' in profile:
+            for read_path in profile['read_path']:
+                newp.add_read_path(read_path)
+
+        if 'write_path' in profile:
+            for write_path in profile['write_path']:
+                newp.add_write_path(write_path)
+
         m.add_profile(newname, newp.profile)
 
     return m.manifest
