@@ -178,7 +178,7 @@ class T(unittest.TestCase):
         c.add_package("com.ubuntu.developer.username.myapp", "0.1")
         security_json = '''{
   "policy_groups": [ "networking" ],
-  "policy_version": "1.0"
+  "policy_version": 1.0
 }'''
         c.add_app('sample-app', manifest=security_json)
 
@@ -194,7 +194,7 @@ class T(unittest.TestCase):
     "com.ubuntu.developer.username.myapp_sample-app_0.1": {
       "policy_groups": [ "networking" ],
       "policy_vendor": "ubuntu",
-      "policy_version": "1.0",
+      "policy_version": 1.0,
       "template": "ubuntu-sdk",
       "template_variables": {
         "APP_ID_DBUS": "%s",
@@ -226,7 +226,7 @@ class T(unittest.TestCase):
         security_json = '''{
   "sample-app": {
     "policy_groups": [ "networking" ],
-    "policy_version": "1.0"
+    "policy_version": 1.0
   }
 }'''
         c.add_app('sample-app', manifest=security_json)
@@ -243,7 +243,7 @@ class T(unittest.TestCase):
     "%s": {
       "policy_groups": [ "networking" ],
       "policy_vendor": "ubuntu",
-      "policy_version": "1.0",
+      "policy_version": 1.0,
       "template": "ubuntu-sdk",
       "template_variables": {
         "APP_ID_DBUS": "%s",
@@ -266,7 +266,7 @@ class T(unittest.TestCase):
                       framework='ubuntu-sdk-13.10')
         security_json = '''{
   "policy_groups": [ "networking" ],
-  "policy_version": "1.0"
+  "policy_version": 1.0
 }'''
         c.add_app('sample-app', manifest=security_json)
 
@@ -282,7 +282,7 @@ class T(unittest.TestCase):
     "%s": {
       "policy_groups": [ "networking" ],
       "policy_vendor": "ubuntu",
-      "policy_version": "1.0",
+      "policy_version": 1.0,
       "template": "ubuntu-sdk",
       "template_variables": {
         "APP_ID_DBUS": "%s",
@@ -304,7 +304,7 @@ class T(unittest.TestCase):
                       framework='unknown-sdk-13.10')
         security_json = '''{
   "policy_groups": [ "networking" ],
-  "policy_version": "1.0"
+  "policy_version": 1.0
 }'''
         c.add_app('sample-app', manifest=security_json)
 
@@ -326,7 +326,7 @@ class T(unittest.TestCase):
         c = self.clickstate
         package = "com.ubuntu.developer.username.yourapp"
         c.add_package(package, "0.3")
-        security_json = '{ "policy_version": "1.0" }'
+        security_json = '{ "policy_version": 1.0 }'
         c.add_app('sample-app', manifest=security_json)
 
         cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
@@ -340,7 +340,7 @@ class T(unittest.TestCase):
     "%s_sample-app_0.3": {
       "policy_groups": [ ],
       "policy_vendor": "ubuntu",
-      "policy_version": "1.0",
+      "policy_version": 1.0,
       "template": "ubuntu-sdk",
       "template_variables": {
         "APP_ID_DBUS": "%s",
@@ -375,7 +375,7 @@ class T(unittest.TestCase):
     "%s_sample-app_0.3": {
       "policy_groups": [ ],
       "policy_vendor": "ubuntu",
-      "policy_version": "1.0",
+      "policy_version": 1.0,
       "template": "ubuntu-sdk",
       "template_variables": {
         "APP_ID_DBUS": "%s",
@@ -400,7 +400,7 @@ class T(unittest.TestCase):
         security_json = '''{
   "template": "unconfined",
   "policy_groups": [ ],
-  "policy_version": "1.0"
+  "policy_version": 1.0
 }'''
         c.add_app('0wnzered', manifest=security_json)
 
@@ -416,7 +416,7 @@ class T(unittest.TestCase):
     "%s_0wnzered_0.99.9~123": {
       "policy_groups": [ ],
       "policy_vendor": "ubuntu",
-      "policy_version": "1.0",
+      "policy_version": 1.0,
       "template": "unconfined",
       "template_variables": {
         "APP_ID_DBUS": "%s",
@@ -440,7 +440,7 @@ class T(unittest.TestCase):
         security_json = '''{
   "template": "unconfined",
   "policy_groups": [ ],
-  "policy_version": "1.0",
+  "policy_version": 1.0,
   "policy_vendor": "somevendor"
 }'''
         c.add_app('0wnzered', manifest=security_json)
@@ -457,7 +457,7 @@ class T(unittest.TestCase):
     "%s_0wnzered_0.99.9~123": {
       "policy_groups": [ ],
       "policy_vendor": "somevendor",
-      "policy_version": "1.0",
+      "policy_version": 1.0,
       "template": "unconfined",
       "template_variables": {
         "APP_ID_DBUS": "%s",
@@ -472,6 +472,289 @@ class T(unittest.TestCase):
                           "Expected to get %s, got %s" % (expected,
                                                           easyprof_manifest))
 
+    def test_parse_security_manifest_policy_version(self):
+        '''Test numeric policy_version'''
+        c = self.clickstate
+        package = "com.ubuntu.developer.username.yourapp"
+        c.add_package(package, "0.3")
+        security_json = '''{
+  "policy_groups": [ "networking" ],
+  "policy_version": 123456789.1234
+}'''
+        c.add_app('sample-app', manifest=security_json)
+
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
+                                          "%s_sample-app_0.3.json" % package))
+        easyprof_manifest = apparmor.click.transform(cm)
+
+        dbus_id = apparmor.click.dbus_path("%s_sample-app_0.3" % package)
+
+        expected = json.loads('''{
+  "profiles": {
+    "%s_sample-app_0.3": {
+      "policy_groups": [
+        "networking"
+      ],
+      "policy_vendor": "ubuntu",
+      "policy_version": 123456789.1234,
+      "template": "ubuntu-sdk",
+      "template_variables": {
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "%s",
+        "APP_VERSION": "0.3",
+        "CLICK_DIR": "%s"
+      }
+    }
+  }
+}''' % (package, dbus_id, package, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" %
+                          (expected, easyprof_manifest))
+
+    def test_parse_security_manifest_policy_version_without_decimal(self):
+        '''Test numeric policy_version without decimal (LP: # 1214618)'''
+        c = self.clickstate
+        package = "com.ubuntu.developer.username.yourapp"
+        c.add_package(package, "0.3")
+        security_json = '''{
+  "policy_groups": [ "networking" ],
+  "policy_version": 1
+}'''
+        c.add_app('sample-app', manifest=security_json)
+
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
+                                          "%s_sample-app_0.3.json" % package))
+        easyprof_manifest = apparmor.click.transform(cm)
+
+        dbus_id = apparmor.click.dbus_path("%s_sample-app_0.3" % package)
+
+        expected = json.loads('''{
+  "profiles": {
+    "%s_sample-app_0.3": {
+      "policy_groups": [
+        "networking"
+      ],
+      "policy_vendor": "ubuntu",
+      "policy_version": 1.0,
+      "template": "ubuntu-sdk",
+      "template_variables": {
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "%s",
+        "APP_VERSION": "0.3",
+        "CLICK_DIR": "%s"
+      }
+    }
+  }
+}''' % (package, dbus_id, package, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" %
+                          (expected, easyprof_manifest))
+
+    # The security policy is supposed to have a JSON Number. The click hook
+    # currently will convert "1.0" to 1.0 for easyprof. Test for that.
+    def test_parse_security_manifest_policy_version_as_string(self):
+        '''Test numeric policy_version as string'''
+        c = self.clickstate
+        package = "com.ubuntu.developer.username.yourapp"
+        c.add_package(package, "0.3")
+        security_json = '''{
+  "policy_groups": [ "networking" ],
+  "policy_version": "1.0"
+}'''
+        c.add_app('sample-app', manifest=security_json)
+
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
+                                          "%s_sample-app_0.3.json" % package))
+        easyprof_manifest = apparmor.click.transform(cm)
+
+        dbus_id = apparmor.click.dbus_path("%s_sample-app_0.3" % package)
+
+        expected = json.loads('''{
+  "profiles": {
+    "%s_sample-app_0.3": {
+      "policy_groups": [
+        "networking"
+      ],
+      "policy_vendor": "ubuntu",
+      "policy_version": 1.0,
+      "template": "ubuntu-sdk",
+      "template_variables": {
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "%s",
+        "APP_VERSION": "0.3",
+        "CLICK_DIR": "%s"
+      }
+    }
+  }
+}''' % (package, dbus_id, package, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" %
+                          (expected, easyprof_manifest))
+
+    # The security policy is supposed to have a JSON Number
+    def test_parse_security_manifest_policy_version_is_number(self):
+        '''Test numeric policy_version requires a number'''
+        c = self.clickstate
+        package = "com.ubuntu.developer.username.yourapp"
+        c.add_package(package, "0.3")
+        v = "abc"
+        security_json = '''{
+  "policy_groups": [ "networking" ],
+  "policy_version": "%s"
+}''' % v
+        c.add_app('sample-app', manifest=security_json)
+
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
+                                          "%s_sample-app_0.3.json" % package))
+        try:
+            apparmor.click.transform(cm)
+        except ValueError:
+            return
+        except Exception:
+            raise
+        raise Exception("version %s should be invalid" % (v))
+
+    def test_parse_security_manifest_abstractions(self):
+        '''Test we pass along abstractions to easyprof'''
+
+        c = self.clickstate
+        appname = "com.ubuntu.developer.trusteddev.terminal"
+        c.add_package(appname, "0.99.9~123")
+        security_json = '''{
+  "template": "ubuntu-sdk",
+  "policy_groups": [ ],
+  "policy_version": 1.0,
+  "abstractions": [
+    "gnupg",
+    "ssl_keys"
+  ]
+}'''
+        c.add_app('0wnzered', manifest=security_json)
+
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
+                                          "%s_0wnzered_0.99.9~123.json" %
+                                          (appname)))
+        easyprof_manifest = apparmor.click.transform(cm)
+
+        dbus_id = apparmor.click.dbus_path("%s_0wnzered_0.99.9~123" % appname)
+
+        expected = json.loads('''{
+  "profiles": {
+    "%s_0wnzered_0.99.9~123": {
+      "abstractions": [ "gnupg", "ssl_keys" ],
+      "policy_groups": [ ],
+      "policy_vendor": "ubuntu",
+      "policy_version": 1.0,
+      "template": "ubuntu-sdk",
+      "template_variables": {
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "%s",
+        "APP_VERSION": "0.99.9~123",
+        "CLICK_DIR": "%s"
+      }
+    }
+  }
+}''' % (appname, dbus_id, appname, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" % (expected,
+                                                          easyprof_manifest))
+
+    def test_parse_security_manifest_read_paths(self):
+        '''Test we pass along read_paths to easyprof'''
+
+        c = self.clickstate
+        appname = "com.ubuntu.developer.trusteddev.terminal"
+        c.add_package(appname, "0.99.9~123")
+        security_json = '''{
+  "template": "ubuntu-sdk",
+  "policy_groups": [ ],
+  "policy_version": 1.0,
+  "read_path": [
+    "/tmp/foo_r",
+    "/tmp/bar_r/"
+  ]
+}'''
+        c.add_app('0wnzered', manifest=security_json)
+
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
+                                          "%s_0wnzered_0.99.9~123.json" %
+                                          (appname)))
+        easyprof_manifest = apparmor.click.transform(cm)
+
+        dbus_id = apparmor.click.dbus_path("%s_0wnzered_0.99.9~123" % appname)
+
+        expected = json.loads('''{
+  "profiles": {
+    "%s_0wnzered_0.99.9~123": {
+      "policy_groups": [ ],
+      "policy_vendor": "ubuntu",
+      "policy_version": 1.0,
+      "read_path": [
+        "/tmp/foo_r",
+        "/tmp/bar_r/"
+      ],
+      "template": "ubuntu-sdk",
+      "template_variables": {
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "%s",
+        "APP_VERSION": "0.99.9~123",
+        "CLICK_DIR": "%s"
+      }
+    }
+  }
+}''' % (appname, dbus_id, appname, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" % (expected,
+                                                          easyprof_manifest))
+
+    def test_parse_security_manifest_write_paths(self):
+        '''Test we pass along write_paths to easyprof'''
+
+        c = self.clickstate
+        appname = "com.ubuntu.developer.trusteddev.terminal"
+        c.add_package(appname, "0.99.9~123")
+        security_json = '''{
+  "template": "ubuntu-sdk",
+  "policy_groups": [ ],
+  "policy_version": 1.0,
+  "write_path": [
+    "/tmp/foo_w",
+    "/tmp/bar_w/"
+  ]
+}'''
+        c.add_app('0wnzered', manifest=security_json)
+
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
+                                          "%s_0wnzered_0.99.9~123.json" %
+                                          (appname)))
+        easyprof_manifest = apparmor.click.transform(cm)
+
+        dbus_id = apparmor.click.dbus_path("%s_0wnzered_0.99.9~123" % appname)
+
+        expected = json.loads('''{
+  "profiles": {
+    "%s_0wnzered_0.99.9~123": {
+      "policy_groups": [ ],
+      "policy_vendor": "ubuntu",
+      "policy_version": 1.0,
+      "write_path": [
+        "/tmp/foo_w",
+        "/tmp/bar_w/"
+      ],
+      "template": "ubuntu-sdk",
+      "template_variables": {
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "%s",
+        "APP_VERSION": "0.99.9~123",
+        "CLICK_DIR": "%s"
+      }
+    }
+  }
+}''' % (appname, dbus_id, appname, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" % (expected,
+                                                          easyprof_manifest))
+
 
 class AppArmorManifestSynchronization(unittest.TestCase):
     def setUp(self):
